@@ -5,7 +5,7 @@ import time
 import os
 import hashlib
 from datetime import datetime, timezone
-from typing import List, Dict, Any, Self
+from typing import List, Dict, Any
 from collections.abc import Iterator
 from abc import ABC, abstractmethod
 from .util.config import Config
@@ -18,7 +18,11 @@ from .modes.mode_controller import ModeController
 from .matching.matcher import Matcher
 from .scanning.scanner import Scanner
 from .util.metadata_parser import MetadataParser
-from .util.error import Error, ErrorCollector, ErrorCommsManager
+from .managers.errors.error import Error
+from .managers.errors.error_collector import ErrorCollector
+from .managers.errors.error_comms import ErrorCommunications
+from .managers.errors.error_manager import ErrorManager
+from .managers.metadata import Metadata
 from .util.printer import StdOutPrinter
 from .util.line_counter import LineCounter
 from .util.exceptions import VariableException, InputException, ParsingException
@@ -72,7 +76,7 @@ class CsvPathPublic(ABC):
         """Advances the iteration by ff rows. -1 means to the end of the file."""
 
     @abstractmethod
-    def fast_forward(self, csvpath: str = None) -> Self:  # pragma: no cover
+    def fast_forward(self, csvpath: str = None):  # pragma: no cover
         """Scans to the end of the CSV file. All scanned rows will be
         considered for match and variables and side effects will happen,
         but no rows will be returned or stored. -1 means to the end of
@@ -102,8 +106,18 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
         skip_blank_lines=True,
         print_default=True,
         config=None,
+        error_manager=None,
     ):
         # re: R0913: all reasonable pass-ins with sensible defaults
+        #
+        # the config.ini file loaded as a ConfigParser instance
+        #
+        # definitely do not want this coming from CsvPaths because
+        # we want to be able to override config.ini specifically for
+        # this instance, if needed; however, we do want to be able
+        # to pass in a config object that has been configured in some
+        # way.
+        self._config = config
         self.scanner = None
         self.matcher = None
         #
@@ -115,6 +129,28 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
         #
         self.csvpaths = csvpaths
         #
+        # there are two logger components one for CsvPath and one for CsvPaths.
+        # the default levels are set in config.ini. to change the levels pass LogUtility
+        # your component instance and the logging level. e.g.:
+        # LogUtility.logger(csvpath, "debug")
+        #
+        self.logger = LogUtility.logger(self)
+        self.logger.info("initialized CsvPath")
+        #
+        # if we don't have a csvpaths these will both be None
+        #
+        self.named_paths_name = None
+        self.named_file_name = None
+        #
+        # all errors come to our manager if they occur during matching. we use
+        # the CsvPaths manager if possible. Otherwise, we just make our own that
+        # only knows how to collect errors, not distribute them.
+        #
+        self.ecoms = ErrorCommunications(csvpath=self)
+        self.error_manager = ErrorManager(csvpath=self)
+        if csvpaths is not None:
+            self.error_manager.add_internal_listener(csvpaths.error_manager)
+        #
         # modes are set in external comments
         #
         self.modes = ModeController(self)
@@ -208,12 +244,11 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
         #
         # error collecting is at the CsvPath instance by default. CsvPath
         # instances that are managed by a CsvPaths have their errors collected
-        # by their ResultsManager. the policy for errors -- their noise level,
-        # effect on validity, etc. -- is set in config.ini at the CsvPath and
-        # CsvPaths level.
+        # by their Results as well. Result handles persistence.
         #
-        self._errors: List[Error] = None
-        self._error_collector = None
+        # errors policies are set in config.ini at CsvPath and CsvPaths levels.
+        #
+        self._errors: List[Error] = []
         #
         # saves the scan and match parts of paths for reference. mainly helpful
         # for testing the CsvPath library itself; not used end users. the run
@@ -245,24 +280,6 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
         if print_default:
             self.printers.append(StdOutPrinter())
         #
-        # the config.ini file loaded as a ConfigParser instance
-        #
-        # definitely do not want this coming from CsvPaths because
-        # we want to be able to override config.ini specifically for
-        # this instance, if needed; however, we do want to be able
-        # to pass in a config object that has been configured in some
-        # way.
-        self._config = config
-        #
-        # there are two logger components one for CsvPath and one for CsvPaths.
-        # the default levels are set in config.ini. to change the levels pass LogUtility
-        # your component instance and the logging level. e.g.:
-        # LogUtility.logger(csvpath, "debug")
-        #
-        self.logger = LogUtility.logger(self)
-        self.logger.info("initialized CsvPath")
-        self._ecoms = ErrorCommsManager(csvpath=self)
-        #
         # _function_times_match collects the time a function spends doing its matches()
         #
         self._function_times_match = {}
@@ -280,6 +297,15 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
         #
         self._unmatched = None
 
+    #
+    # this method saves and reloads the config. if you don't want that use
+    # CsvPath.config.save_to_config().
+    #
+    def add_to_config(self, section, key, value) -> None:
+        self.config.add_to_config(section=section, key=key, value=value)
+        self.config.save_config()
+        self.config.reload()
+
     @property
     def data_from_preceding(self) -> bool:
         return self.modes.source_mode.value
@@ -357,7 +383,7 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
         return self._function_times_value
 
     def do_i_raise(self) -> bool:
-        return self._ecoms.do_i_raise()
+        return self.ecoms.do_i_raise()
 
     @property
     def advance_count(self) -> int:  # pragma: no cover
@@ -445,41 +471,30 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
             self._config = Config()
         return self._config
 
-    def has_errors(self) -> bool:
-        if self.errors and len(self.errors) > 0:
-            return True
-        if self.error_collector:
-            return self.error_collector.has_errors()
-        return False
+    # ==========================
+    # Errors
+    # <thinking> if we have a csvpaths people should look at the result to find errors
+    # but we give access to metadata, vars, etc. from the csvpath, so we should
+    # give errors too. that means we need to have our own listener. ultimately we'd
+    # just be adding pointers, not dup the original error data.
+    #
+    def metadata_update(self, mdata: Metadata) -> None:
+        if isinstance(mdata, Error):
+            self.collect_error(mdata)
 
     @property
     def errors(self) -> List[Error]:  # pylint: disable=C0116
-        return (
-            self._errors
-            if self._error_collector is None
-            else self._error_collector.errors
-        )
+        return self._errors
 
     @property
-    def error_collector(self):  # pylint: disable=C0116
-        return self._error_collector
-
-    @error_collector.setter
-    def error_collector(self, error_collector) -> None:
-        self._error_collector = error_collector
+    def errors_count(self) -> int:  # pylint: disable=C0116
+        return len(self.errors)
 
     def collect_error(self, error: Error) -> None:  # pylint: disable=C0116
-        #
-        # errors must be built and handled in ErrorHandler.
-        # here we're just collecting them if collect is
-        # selected by our configuration
-        #
-        if self._error_collector is not None:
-            self._error_collector.collect_error(error)
-        else:
-            if self._errors is None:
-                self._errors = []
-            self._errors.append(error)
+        self.errors.append(error)
+
+    def has_errors(self) -> bool:
+        return self.errors_count > 0
 
     @property
     def stop_on_validation_errors(self) -> bool:
@@ -505,6 +520,10 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
     def match_validation_errors(self) -> bool:
         return self.modes.validation_mode.match_validation_errors
 
+    @property
+    def collect_validation_errors(self) -> bool:
+        return self.modes.validation_mode.collect_validation_errors
+
     def add_printer(self, printer) -> None:  # pylint: disable=C0116
         if printer not in self.printers:
             self.printers.append(printer)
@@ -596,8 +615,12 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
         self.update_settings_from_metadata()
         #
         #
+        # exp!
+        if disposably is False:
+            csvpath = self._update_file_path(csvpath)
+        #
+        #
         #
-        csvpath = self._update_file_path(csvpath)
         s, mat = self._find_scan_and_match_parts(csvpath)
         #
         # a disposable matcher still needs the match part
@@ -656,6 +679,10 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
     def source_mode(self) -> str:
         return self.metadata.get("source-mode")
 
+    @property
+    def error_mode(self) -> str:
+        return self.metadata.get("error-mode")
+
     @property
     def files_mode(self) -> str:
         return self.metadata.get("files-mode")
@@ -722,7 +749,7 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
         for p in np:
             # this ends up being redundant to the caller. we do it 1x so it's not
             # a big lift and is consistent.
-            c = CsvPath()
+            c = CsvPath(csvpaths=self.csvpaths)
             MetadataParser(c).extract_metadata(instance=c, csvpath=p)
             if c.identity == specific:
                 return p
@@ -742,9 +769,13 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
             raise CsvPathsException("No CsvPaths object available")
 
         path = self._pick_named_path(name, specific=specific)
-        c = CsvPath()
+        c = CsvPath(csvpaths=self.csvpaths)
         path = MetadataParser(c).extract_metadata(instance=c, csvpath=path)
-        path = c._update_file_path(path)
+        #
+        # exp. oddly this seems to be superfluous
+        # if disposably is False:
+        #    path = c._update_file_path(path)
+        #
         dis = c.parse(path, disposably=disposably)
         if disposably is True:
             return dis
@@ -906,6 +937,10 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
     #
     # collect(), fast_forward(), and next() are the central methods of CsvPath.
     #
+    # remember that since next() is a public method and collect() and fast_forward()
+    # rely on it, we have to cut off exceptions at next(). users will not see
+    # fast_forward and collect in the stack trace. probably that's not a big deal.
+    # if it seems confusing we can work around the problem.
     #
     def collect(
         self, csvpath: str = None, *, nexts: int = -1, lines=None
@@ -965,7 +1000,7 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
             self.lines = None
         return lines
 
-    def fast_forward(self, csvpath=None) -> Self:
+    def fast_forward(self, csvpath=None):
         """Runs the path for all rows of the file. Variables are collected
         and side effects like print happen. No lines are collected.
         """
@@ -975,56 +1010,68 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
             pass
         return self
 
+    #
+    # dont_raise is for the use of fast_forward and collect who
+    # may want to handle raising errors themselves.
+    #
     def next(self, csvpath=None):
         """Iterates over the lines in the CSV file returning those that match
         the csvpath. collect() and fast_forward() call next() behind the scenes.
         """
-        if self.scanner is None and csvpath is not None:
-            self.parse(csvpath)
-        start = time.time()
-        if self.will_run is True:
-            for line in self._next_line():
-                b = self._consider_line(line)
-                if b:
-                    line = self.limit_collection(line)
-                    if line is None:
-                        msg = "Line cannot be None"
-                        self.logger.error(msg)
-                        raise MatchException(msg)
-                    if len(line) == 0:
-                        msg = "Line cannot be len() == 0"
-                        self.logger.error(msg)
-                        raise MatchException(msg)
-                    yield line
-                elif self.collecting and self.unmatched_available:
-                    if self.unmatched is None:
-                        self.unmatched = []
-                    line = self.limit_collection(line)
-                    # we aren't None and 0 checking as above. needed?
-                    self.unmatched.append(line)
-                if self.stopped:
-                    self.logger.info(
-                        "CsvPath has been stopped at line %s",
-                        self.line_monitor.physical_line_number,
-                    )
-                    break
-        else:
-            self.logger.warning(
-                "Csvpath identified as {self.identity} is disabled by run-mode:no-run"
+        try:
+            if self.scanner is None and csvpath is not None:
+                self.parse(csvpath)
+            start = time.time()
+            if self.will_run is True:
+                for line in self._next_line():
+                    b = self._consider_line(line)
+                    if b:
+                        line = self.limit_collection(line)
+                        if line is None:
+                            msg = "Line cannot be None"
+                            self.logger.error(msg)
+                            raise MatchException(msg)
+                        if len(line) == 0:
+                            msg = "Line cannot be len() == 0"
+                            self.logger.error(msg)
+                            raise MatchException(msg)
+                        yield line
+                    elif self.collecting and self.unmatched_available:
+                        if self.unmatched is None:
+                            self.unmatched = []
+                        line = self.limit_collection(line)
+                        # we aren't None and 0 checking as above. needed?
+                        self.unmatched.append(line)
+                    if self.stopped:
+                        self.logger.info(
+                            "CsvPath has been stopped at line %s",
+                            self.line_monitor.physical_line_number,
+                        )
+                        break
+            else:
+                self.logger.warning(
+                    "Csvpath identified as {self.identity} is disabled by run-mode:no-run"
+                )
+            self.finalize()
+            end = time.time()
+            self.total_iteration_time = end - start
+            self.logger.info("Run against %s is complete.", self.scanner.filename)
+            self.logger.info(
+                "Iteration time was %s", round(self.total_iteration_time, 2)
             )
-        self.finalize()
-        # moving to finalize
-        # self._freeze_path = True
-        end = time.time()
-        self.total_iteration_time = end - start
-        self.logger.info("Run against %s is complete.", self.scanner.filename)
-        self.logger.info("Iteration time was %s", round(self.total_iteration_time, 2))
-        self.logger.info(
-            "%s per line",
-            round(
-                self.total_iteration_time / self.line_monitor.physical_end_line_count, 2
-            ),
-        )
+            self.logger.info(
+                "%s per line",
+                round(
+                    self.total_iteration_time
+                    / self.line_monitor.physical_end_line_count,
+                    2,
+                ),
+            )
+        except Exception as e:
+            if not self.ecoms.do_i_quiet():
+                self.logger.error(e, exc_info=True)
+            if self.ecoms.do_i_raise():
+                raise
 
     def _next_line(self) -> List[Any]:
         self.logger.info("beginning to scan file: %s", self.scanner.filename)
@@ -1204,6 +1251,9 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
                 "Csvpath identified as %s has no filename. Since we could be error handling an exception is not raised.",
                 self.identity,
             )
+            # exp
+            return
+            # end exp
         #
         # there are times, e.g. when using Lambda, when it may be better to
         # not use a cache. in the case of Lambda the reason is to avoid working
@@ -1258,6 +1308,13 @@ class CsvPath(CsvPathPublic, ErrorCollector, Printer):  # pylint: disable=R0902,
                 csvpath=self, data=self.match, line=line, headers=self.headers, myid=h
             )
             self.matcher.AND = self.AND
+            #
+            # we need to register all the Expressions as error listeners. not
+            # sure it matters if we do it here or allow the Matcher to do it.
+            # since the Matcher is responsible for its Expressions, has a handle
+            # this CsvPath, and through it has the error_manager let's let it
+            # register the expressions.
+            #
         else:
             self.logger.debug("Resetting and reloading matcher")
             self.matcher.reset()
