@@ -4,13 +4,16 @@ from .function import Function
 from .function_finder import FunctionFinder
 from .dates.now import Now
 from .strings.lower import Lower
+from .strings.contains import Contains
 from .strings.upper import Upper
+from .strings.caps import Capitalize
 from .strings.substring import Substring
 from .strings.starts_with import StartsWith
 from .strings.strip import Strip
 from .strings.length import Length, MinMaxLength
 from .strings.regex import Regex
 from .strings.concat import Concat
+from .strings.alter import Alter
 from .strings.metaphone import Metaphone
 from .counting.count import Count
 from .counting.count_bytes import CountBytes
@@ -39,6 +42,7 @@ from .math.subtract import Subtract
 from .math.multiply import Multiply
 from .math.divide import Divide
 from .math.intf import Int, Float  # , Num
+from .math.odd import Odd
 from .math.sum import Sum
 from .math.subtotal import Subtotal
 from .math.equals import Equals
@@ -87,6 +91,8 @@ from .types.nonef import Nonef, Blank, Wildcard
 from .types.decimal import Decimal
 from .types.boolean import Boolean
 from .types.datef import Date
+from .types.email import Email
+from .types.url import Url
 from .types.string import String
 
 
@@ -176,10 +182,16 @@ class FunctionFactory:
             f = In(matcher, name, child)
         elif name == "concat":
             f = Concat(matcher, name, child)
+        elif name in ["contains", "find"]:
+            f = Contains(matcher, name, child)
         elif name == "lower":
             f = Lower(matcher, name, child)
         elif name == "upper":
             f = Upper(matcher, name, child)
+        elif name == "caps":
+            f = Capitalize(matcher, name, child)
+        elif name == "alter":
+            f = Alter(matcher, name, child)
         elif name == "percent":
             f = Percent(matcher, name, child)
         elif name in ["below", "lt", "before", "lte"]:
@@ -241,7 +253,7 @@ class FunctionFactory:
             f = Tally(matcher, name, child)
         elif name == "every":
             f = Every(matcher, name, child)
-        elif name == "print":
+        elif name in ["print", "error"]:
             f = Print(matcher, name, child)
         elif name == "increment":
             f = Increment(matcher, name, child)
@@ -275,7 +287,7 @@ class FunctionFactory:
             f = Exists(matcher, name, child)
         elif name == "mod":
             f = Mod(matcher, name, child)
-        elif name in ["equals", "eq"]:
+        elif name in ["equals", "equal", "eq", "not_equal_to", "neq"]:
             f = Equals(matcher, name, child)
         elif name == "strip":
             f = Strip(matcher, name, child)
@@ -341,13 +353,19 @@ class FunctionFactory:
             f = Track(matcher, name, child)
         elif name == "sum":
             f = Sum(matcher, name, child)
+        elif name in ["odd", "even"]:
+            f = Odd(matcher, name, child)
+        elif name == "email":
+            f = Email(matcher, name, child)
+        elif name == "url":
+            f = Url(matcher, name, child)
         elif name == "subtotal":
             f = Subtotal(matcher, name, child)
         elif name == "reset_headers":
             f = ResetHeaders(matcher, name, child)
-        elif name == "starts_with":
+        elif name in ["starts_with", "startswith", "ends_with", "endswith"]:
             f = StartsWith(matcher, name, child)
-        elif name == "skip":
+        elif name in ["skip", "take"]:
             f = Skip(matcher, name, child)
         elif name == "skip_all":
             f = SkipAll(matcher, name, child)
