@@ -12,7 +12,7 @@ class Replace(SideEffect):
     def check_valid(self) -> None:
         self.args = Args(matchable=self)
         a = self.args.argset(2)
-        a.arg(types=[Term], actuals=[int, str])
+        a.arg(types=[Term, Header], actuals=[int, str])
         a.arg(types=[Term, Variable, Header, Function, Reference], actuals=[Any])
         self.args.validate(self.siblings())
         super().check_valid()
@@ -21,14 +21,20 @@ class Replace(SideEffect):
         self._apply_default_value()
 
     def _decide_match(self, skip=None) -> None:
-        h = self._value_one(skip=skip)
+        header = None
+        c = self._child_one()
+        if isinstance(c, Header):
+            header = c.name
+        else:
+            header = self._value_one(skip=skip)
+        i = header
+        if not isinstance(header, int):
+            i = self.matcher.header_index(header)
+
         val = self._value_two(skip=skip)
-        i = h
-        if not isinstance(h, int):
-            i = self.matcher.header_index(h)
 
         self.matcher.csvpath.logger.debug(
-            "Replacing %s idenified as %s with %s", self.matcher.line[i], h, val
+            "Replacing %s idenified as %s with %s", self.matcher.line[i], header, val
         )
         self.matcher.line[i] = val
 
