@@ -36,4 +36,8 @@ class Subtract(ValueProducer):
         return ret
 
     def _decide_match(self, skip=None) -> None:
+        # we want to_value called so that if we would blow-up in
+        # assignment, equality, etc. we still blow-up even though we're not
+        # using the difference.
+        self.to_value(skip=skip)
         self.match = self.default_match()
