@@ -16,11 +16,15 @@ class Regex(MatchDecider):
         a = self.args.argset(3)
         a.arg(
             types=[Term, Variable, Header, Function, Reference],
-            actuals=[str, self.args.EMPTY_STRING],
+            actuals=[str, self.args.EMPTY_STRING, None],
         )
+        #
+        # because we accept the regex in 0 or 1 we have to accept None
+        # as an actual value in both.
+        #
         a.arg(
             types=[Term, Variable, Header, Function, Reference],
-            actuals=[str, self.args.EMPTY_STRING],
+            actuals=[str, self.args.EMPTY_STRING, None],
         )
         a.arg(types=[None, Term, Variable, Header, Function, Reference], actuals=[int])
         self.args.validate(self.siblings())
@@ -57,7 +61,10 @@ class Regex(MatchDecider):
             return theregex, thevalue, group
         else:
             # correct structure / children exception
-            self.raise_children_exception("No regular expression available")
+            msg = "No regular expression available"
+            self.matcher.csvpath.error_manager.handle_error(source=self, msg=msg)
+            if self.matcher.csvpath.do_i_raise():
+                raise ChildrenException(msg)
 
     def _produce_value(self, skip=None) -> None:
         child = self.children[0]
