@@ -5,3 +5,5 @@ from csvpath.matching.functions.types.string import String
 from csvpath.matching.functions.types.decimal import Decimal
 from csvpath.matching.functions.types.nonef import Nonef, Blank, Wildcard
 from csvpath.matching.functions.types.datef import Date
+from csvpath.matching.functions.types.url import Url
+from csvpath.matching.functions.types.email import Email
