@@ -1,6 +1,6 @@
 # pylint: disable=C0114
 from csvpath.matching.util.expression_utility import ExpressionUtility
-from csvpath.matching.util.exceptions import ChildrenException
+from csvpath.matching.util.exceptions import MatchException
 from csvpath.matching.productions import Term, Variable, Header
 from ..function import Function, CheckedUnset
 from ..function_focus import ValueProducer
@@ -24,18 +24,27 @@ class Boolean(ValueProducer):
             v = c.to_value(skip=skip)
         if v is None or f"{v}".strip() == "":
             self.value = CheckedUnset()
-            # self.value = None
+            #
+            # pretty sure this none should be caught by the args validation
+            #
             if self.notnone is True:
-                msg = self.decorate_error_message("Value cannot be empty")
-                self.parent.raise_if(ChildrenException(msg))
+                msg = "Value cannot be empty because notnone is set"
+                self.matcher.csvpath.error_manager.handle_error(source=self, msg=msg)
+                if self.matcher.csvpath.do_i_raise():
+                    raise MatchException(msg)
         else:
             v = ExpressionUtility.to_bool(v)
             if v in [True, False]:
                 self.value = v
             else:
                 self.value = CheckedUnset()
-                msg = self.decorate_error_message(f"Not a boolean value: '{v}'")
-                self.parent.raise_if(ChildrenException(msg))
+                #
+                # pretty sure this none should also be caught by Args
+                #
+                msg = f"Not a boolean value in {self.my_chain}: '{v}'"
+                self.matcher.csvpath.error_manager.handle_error(source=self, msg=msg)
+                if self.matcher.csvpath.do_i_raise():
+                    raise MatchException(msg)
 
     def _decide_match(self, skip=None) -> None:
         # we need to make sure a value is produced so that we see
