@@ -47,6 +47,15 @@ class Sections(Enum):
     CACHE = "cache"
 
 
+#
+# main external methods:
+#  - load
+#  - save
+#  - refresh
+#  - reload
+#  - add_to_config
+#  - get
+#
 class Config:
     """by default finds config files at ./config/config.ini.
     To set a different location:
@@ -57,7 +66,7 @@ class Config:
     properties programmatically.
     """
 
-    CONFIG: str = "config/config.ini"
+    CONFIG: str = f"config{os.sep}config.ini"
     CSVPATH_CONFIG_FILE_ENV: str = "CSVPATH_CONFIG_PATH"
 
     def __init__(self, *, load=True):
@@ -126,13 +135,22 @@ class Config:
                 print(f"Check config at {self.config_path} for [{section}][{name}]")
             return default
 
-    def add_to_config(self, section, key, value, save_load: bool = True) -> None:
+    #
+    # adds the value to the internal configparser object. doesn't save.
+    # does a refresh to make sure any lists or other interpreted values
+    # are up to date. if you want to save you need to call the save
+    # method.
+    #
+    def add_to_config(self, section, key, value) -> None:
         if not self._config.has_section(section):
             self._config.add_section(section)
-        self._config.set(section, key, value)
-        if save_load is True:
-            self.save_config()
-            self._load_config()
+        #
+        # values must be strings
+        #
+        if value is None:
+            value = ""
+        self._config[section][key] = value
+        self.refresh()
 
     def save_config(self) -> None:
         with open(self.configpath, "w") as f:
@@ -151,39 +169,56 @@ class Config:
             if not path.exists(directory):
                 os.makedirs(directory)
         with open(self._configpath, "w", encoding="utf-8") as file:
-            c = """
+            c = f"""
 [csvpath_files]
 extensions = txt, csvpath, csvpaths
+
 [csv_files]
 extensions = txt, csv, tsv, dat, tab, psv, ssv
+
 [errors]
 csvpath = collect, fail, print
 csvpaths = raise, collect
+use_format = full
+pattern = {{time}}:{{file}}:{{line}}:{{paths}}:{{instance}}:{{chain}}:  {{message}}
+
 [logging]
 csvpath = info
 csvpaths = info
-log_file = logs/csvpath.log
+log_file = logs{os.sep}csvpath.log
 log_files_to_keep = 100
 log_file_size = 52428800
+
 [config]
 path =
+
 [functions]
 imports =
+
 [cache]
 path =
 
 [listeners]
 # add listener group names to send events to the channel they represent
-groups =
+groups = default
 #slack, marquez, ckan, sftp, sftpplus, otlp
 
+# add to capture a history of all named-file stagings and all named-paths loads in
+# an [inputs] files and an[inputs] paths root manifest.json
+default.file = from csvpath.managers.files.files_listener import FilesListener
+default.paths = from csvpath.managers.paths.paths_listener import PathsListener
+
 # add otlp to the list of groups above to push observability metrics to an OpenTelemetry endpoint
 otlp.result = from csvpath.managers.integrations.otlp.otlp_result_listener import OpenTelemetryResultListener
 otlp.results = from csvpath.managers.integrations.otlp.otlp_results_listener import OpenTelemetryResultsListener
+otlp.errors = from csvpath.managers.integrations.otlp.otlp_error_listener import OpenTelemetryErrorListener
 
 # add sftp to the list of groups above to push content and metadata to an SFTP account
 sftp.results = from csvpath.managers.integrations.sftp.sftp_listener import SftpListener
 
+# add sftpplus to the list of groups above to automate registration and named-paths group runs on file arrival at an SFTPPlus server
+sftpplus.paths = from csvpath.managers.integrations.sftpplus.sftpplus_listener import SftpPlusListener
+
 # add ckan to the list of groups above to push content and metadata to CKAN
 ckan.results = from csvpath.managers.integrations.ckan.ckan_listener import CkanListener
 
@@ -200,11 +235,20 @@ slack.result = from csvpath.managers.integrations.slack.sender import SlackSende
 slack.results = from csvpath.managers.integrations.slack.sender import SlackSender
 
 [sftpplus]
-admin_user = SFTPPLUS_ADMIN_USERNAME
+# these are only needed on the server
+admin_username = SFTPPLUS_ADMIN_USERNAME
 admin_password = SFTPPLUS_ADMIN_PASSWORD
+api_url = https://localhost:10020/json
+scripts_dir =
+execute_timeout = 300
+
+# these are only needed by the csvpath writer
+mailbox_user = mailbox
+mailbox_password = SFTPPLUS_MAILBOX_PASSWORD
 server = SFTPPLUS_SERVER
 port = SFTPPLUS_PORT
 
+
 [ckan]
 server = http://localhost:80
 api_token =
@@ -226,8 +270,8 @@ webhook_url =
 archive = archive
 transfers = transfers
 [inputs]
-files = inputs/named_files
-csvpaths = inputs/named_paths
+files = inputs{os.sep}named_files
+csvpaths = inputs{os.sep}named_paths
 on_unmatched_file_fingerprints = halt
             """
             file.write(c)
@@ -239,7 +283,7 @@ on_unmatched_file_fingerprints = halt
         if self.load:
             filepath = self.log_file
             if not filepath or filepath.strip() == "":
-                filepath = "logs/csvpath.log"
+                filepath = f"logs{os.sep}csvpath.log"
                 self.log_file = filepath
             dirpath = self._get_dir_path(filepath)
             if dirpath and not path.exists(dirpath):
@@ -270,7 +314,7 @@ on_unmatched_file_fingerprints = halt
     def _assure_inputs_files_path(self) -> None:
         if self.load:
             if self.inputs_files_path is None or self.inputs_files_path.strip() == "":
-                self.inputs_files_path = "inputs/named_files"
+                self.inputs_files_path = f"inputs{os.sep}named_files"
             if self.inputs_files_path.strip().lower().startswith("s3://"):
                 return
             if not path.exists(self.inputs_files_path):
@@ -282,7 +326,7 @@ on_unmatched_file_fingerprints = halt
                 self.inputs_csvpaths_path is None
                 or self.inputs_csvpaths_path.strip() == ""
             ):
-                self.inputs_csvpaths_path = "inputs/named_paths"
+                self.inputs_csvpaths_path = f"inputs{os.sep}named_paths"
             if self.inputs_csvpaths_path.strip().lower().startswith("s3://"):
                 return
             if not path.exists(self.inputs_csvpaths_path):
@@ -316,6 +360,14 @@ on_unmatched_file_fingerprints = halt
         #
         #
         self._config.read(self._configpath)
+        self.refresh()
+
+    #
+    # we hold lists and such that may need refreshing from the configparser
+    # object, if that has been updated or loaded. this method doesn't load from
+    # file, it just gathers and translates settings for external use.
+    #
+    def refresh(self) -> None:
         self.csvpath_file_extensions = self._get(
             Sections.CSVPATH_FILES.value, "extensions"
         )
@@ -527,7 +579,7 @@ on_unmatched_file_fingerprints = halt
             self._inputs_files_path = self._get("inputs", "files")
             if self._inputs_files_path is None:
                 self._inputs_files_path = "inputs"
-                self.add_to_config("inputs", "files", "inputs/named_files")
+                self.add_to_config("inputs", "files", f"inputs{os.sep}named_files")
         return self._inputs_files_path
 
     @inputs_files_path.setter
@@ -540,7 +592,7 @@ on_unmatched_file_fingerprints = halt
             self._inputs_csvpaths_path = self._get("inputs", "csvpaths")
             if self._inputs_csvpaths_path is None:
                 self._inputs_csvpaths_path = "inputs"
-                self.add_to_config("inputs", "csvpaths", "inputs/named_paths")
+                self.add_to_config("inputs", "csvpaths", f"inputs{os.sep}named_paths")
         return self._inputs_csvpaths_path
 
     @inputs_csvpaths_path.setter
