@@ -31,7 +31,6 @@ class FileInfo:
             "created": None,
             "last_read": None,
             "last_mod": None,
-            "flags": None,
         }
 
     @classmethod
@@ -44,6 +43,5 @@ class FileInfo:
             "created": s.st_ctime,
             "last_read": s.st_atime,
             "last_mod": s.st_mtime,
-            "flags": s.st_flags,
         }
         return meta
