@@ -7,6 +7,7 @@ from ..file_readers import XlsxDataReader
 from .s3_fingerprinter import S3Fingerprinter
 from csvpath.util.box import Box
 from csvpath.util.s3.s3_utils import S3Utils
+from csvpath.util.hasher import Hasher
 
 
 class S3XlsxDataReader(XlsxDataReader):
@@ -33,6 +34,6 @@ class S3XlsxDataReader(XlsxDataReader):
     def fingerprint(self) -> str:
         self.load_if()
         h = S3Fingerprinter().fingerprint(self._path)
-        h = self.percent_encode(h)
+        h = Hasher.percent_encode(h)
         self.close()
         return h
